@@ -710,7 +710,7 @@ void tournament(double *fitnesses, int *winners, double *paras){
     sampleK  = (int) paras[24];
     chooseK  = (int) paras[25];
     
-    samples  = malloc(sampleK * sizeof(double));
+    samples  = malloc(sampleK * sizeof(int));
     samp_fit = malloc(sampleK * sizeof(double));
     placed   = 0;
     
@@ -819,12 +819,18 @@ void ga(double ***ACTION, double ***COST, double **AGENT, double **RESOURCES,
     agentID        = (int) AGENT[agent][0];
     
     most_fit       = 0;
-    budget         = AGENT[agent][16] + AGENT[agent][24] + AGENT[agent][25]; 
+    budget         = AGENT[agent][16] + AGENT[agent][24] + AGENT[agent][25];
+    
     if(budget < 1){
       budget = 1;
     }
     if(budget > 100001){
       budget = 100000;
+    } 
+    
+    /* store final budget in paras vector */
+    if (managing == 1) {
+        paras[131] = budget;
     }
     
     POPULATION = malloc(xdim * sizeof(double *));
