@@ -37,7 +37,7 @@ test_that("Dimensions of observation arrays in user model are correct", {
                17, 18, 19, 20, 21, 0.5, 1, 2, 15, 0, 0, 0, 0, 0, 1, 1, 1, 1, 
                1, 1, 1, 1, 10, 1000, 100, 100, 0, 0, 10, 0, 0, 0, 1, 0, 0, 0, 0,
                1, 16, 1000, 10, 20, 0, 0, 21, 0, 13, 1, 22, 23, 1, 0, 0, 
-               24, 25);
+               24, 25, 0, 0, 0, 0, 0, 0, 0);
     
     agents  <-  make_agents(model        = "IBM",
                             agent_number = 2,
@@ -126,7 +126,7 @@ test_that("Users act according to costs", {
                17, 18, 19, 20, 21, 0.5, 1, 2, 15, 0, 0, 0, 0, 0, 1, 1, 1, 1, 
                1, 1, 1, 1, 10, 1000, 100, 100, 0, 0, 10, 0, 0, 0, 1, 0, 0, 0, 0,
                1, 16, 1000, 10, 20, 0, 0, 21, 0, 13, 1, 22, 23, 1, 0, 0, 
-               24, 25);
+               24, 25, 0, 0, 0, 0, 0, 0, 0);
     
     agents  <-  make_agents(model        = "IBM",
                             agent_number = 2,
@@ -213,7 +213,7 @@ test_that("Managers don't act like users", {
                17, 18, 19, 20, 21, 0.5, 1, 2, 15, 0, 0, 0, 0, 0, 1, 1, 1, 1, 
                1, 1, 1, 1, 10, 1000, 100, 100, 0, 0, 10, 0, 0, 0, 1, 0, 0, 0, 0,
                1, 16, 1000, 10, 20, 0, 0, 21, 0, 13, 1, 22, 23, 1, 0, 0, 
-               24, 25);
+               24, 25, 0, 0, 0, 0, 0, 0, 0);
     
     agents  <-  make_agents(model        = "IBM",
                             agent_number = 2,
